@@ -3,7 +3,7 @@
 
 /* eslint-disable no-redeclare */
 var Sao = {
-    __version__: '7.0.27',
+    __version__: '7.0.38',
 };
 /* eslint-enable no-redeclare */
 
@@ -630,6 +630,7 @@ var Sao = {
                                 "Incompatible version of the server."),
                             Sao.i18n.gettext("Version mismatch"));
                     } else {
+                        let url = window.location.hash.substr(1);
                         Sao.Session.get_credentials()
                             .then(function(session) {
                                 Sao.Session.current_session = session;
@@ -639,7 +640,7 @@ var Sao = {
                             .then(function(preferences) {
                                 Sao.menu(preferences);
                                 Sao.user_menu(preferences);
-                                Sao.open_url();
+                                Sao.open_url(url);
                                 Sao.Bus.listen();
                             });
                     }
@@ -1135,20 +1136,26 @@ var Sao = {
                 shortcut: 'alt+shift+tab',
                 label: Sao.i18n.gettext('Previous tab'),
                 callback: function() {
-                    Sao.Tab.previous_tab();
+                    if (!jQuery('body').children('.modal').length) {
+                        Sao.Tab.previous_tab();
+                    }
                 },
             }, {
                 shortcut: 'alt+tab',
                 label: Sao.i18n.gettext('Next tab'),
                 callback: function() {
-                    Sao.Tab.next_tab();
+                    if (!jQuery('body').children('.modal').length) {
+                        Sao.Tab.next_tab();
+                    }
                 },
             }, {
                 shortcut: 'ctrl+k',
                 label: Sao.i18n.gettext('Global search'),
                 callback: function() {
-                    jQuery('#main_navbar:hidden').collapse('show');
-                    jQuery('#global-search-entry').focus();
+                    if (!jQuery('body').children('.modal').length) {
+                        jQuery('#main_navbar:hidden').collapse('show');
+                        jQuery('#global-search-entry').focus();
+                    }
                 },
             }, {
                 shortcut: 'f1',
